.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

==================
contenttypes.basic
==================

This addon provides the common content-types. fields, widgets and behaviors.

Features
--------

- Permissions
- Indexers
- Behaviors
- Fields
- Content-types
    - Announcement
    - Banner
    - Icon
    - Slide
- Widgets
    - Colour
    - Icon
    - Map


Translations
------------

This product has been translated into

- Catalan
- Spanish
- English


Installation
------------

Install contenttypes.basic by adding it to your buildout::

    [buildout]

    ...

    eggs =
        contenttypes.basic


and then running ``bin/buildout``



Classifiers
-----------

Framework

- Plone 5.2

Programming Language

- Python 3.6
- Python 3.7


License
-------

The project is licensed under the GPLv2.
